==> foreman-installer-3.15.1.tar.bz2: foreman-installer-3.15.1/modules/tftp/CHANGELOG.md <==
# Changelog

## [9.1.0](https://github.com/theforeman/puppet-tftp/tree/9.1.0) (2024-05-16)

[Full Changelog](https://github.com/theforeman/puppet-tftp/compare/9.0.0...9.1.0)

**Implemented enhancements:**

- Add support for Debian 12 [\#149](https://github.com/theforeman/puppet-tftp/pull/149) ([evgeni](https://github.com/evgeni))
- Add Ubuntu 22.04 support [\#148](https://github.com/theforeman/puppet-tftp/pull/148) ([evgeni](https://github.com/evgeni))

## [9.0.0](https://github.com/theforeman/puppet-tftp/tree/9.0.0) (2023-11-14)

[Full Changelog](https://github.com/theforeman/puppet-tftp/compare/8.0.0...9.0.0)

**Breaking changes:**

- Drop Fedora support [\#145](https://github.com/theforeman/puppet-tftp/pull/145) ([ekohl](https://github.com/ekohl))
- Drop Puppet 6 support [\#144](https://github.com/theforeman/puppet-tftp/pull/144) ([ekohl](https://github.com/ekohl))
- Drop Ubuntu 18.04 & Debian 9, add Red Hat 9 support [\#142](https://github.com/theforeman/puppet-tftp/pull/142) ([dvo-rak](https://github.com/dvo-rak))

**Implemented enhancements:**

- Add Puppet 8 support [\#140](https://github.com/theforeman/puppet-tftp/pull/140) ([bastelfreak](https://github.com/bastelfreak))
- puppetlabs/stdlib: Allow 9.x [\#139](https://github.com/theforeman/puppet-tftp/pull/139) ([bastelfreak](https://github.com/bastelfreak))
- make syslinux package management optional [\#138](https://github.com/theforeman/puppet-tftp/pull/138) ([UiP9AV6Y](https://github.com/UiP9AV6Y))

## [8.0.0](https://github.com/theforeman/puppet-tftp/tree/8.0.0) (2022-10-27)

[Full Changelog](https://github.com/theforeman/puppet-tftp/compare/7.2.0...8.0.0)

**Breaking changes:**

- Drop xinetd support [\#136](https://github.com/theforeman/puppet-tftp/pull/136) ([ekohl](https://github.com/ekohl))

**Implemented enhancements:**

- Update to voxpupuli-test 5 [\#135](https://github.com/theforeman/puppet-tftp/pull/135) ([ekohl](https://github.com/ekohl))

## [7.2.0](https://github.com/theforeman/puppet-tftp/tree/7.2.0) (2022-04-20)

[Full Changelog](https://github.com/theforeman/puppet-tftp/compare/7.1.0...7.2.0)

**Implemented enhancements:**

- CentOS Stream 9 support [\#126](https://github.com/theforeman/puppet-tftp/pull/126) ([ekohl](https://github.com/ekohl))

## [7.1.0](https://github.com/theforeman/puppet-tftp/tree/7.1.0) (2022-02-03)

[Full Changelog](https://github.com/theforeman/puppet-tftp/compare/7.0.0...7.1.0)

**Implemented enhancements:**

- puppetlabs/stdlib: Allow 8.x [\#129](https://github.com/theforeman/puppet-tftp/pull/129) ([bastelfreak](https://github.com/bastelfreak))
- Add Debian 11 support [\#125](https://github.com/theforeman/puppet-tftp/pull/125) ([ekohl](https://github.com/ekohl))

## [7.0.0](https://github.com/theforeman/puppet-tftp/tree/7.0.0) (2021-07-23)

[Full Changelog](https://github.com/theforeman/puppet-tftp/compare/6.0.0...7.0.0)

**Breaking changes:**

- Drop EL6, Debian 8, Ubuntu 16.04 [\#122](https://github.com/theforeman/puppet-tftp/pull/122) ([ehelms](https://github.com/ehelms))
- Drop Puppet 5 support [\#120](https://github.com/theforeman/puppet-tftp/pull/120) ([ehelms](https://github.com/ehelms))

**Implemented enhancements:**

- Allow Puppet 7 compatible versions of mods [\#116](https://github.com/theforeman/puppet-tftp/pull/116) ([ekohl](https://github.com/ekohl))
- Support Ubuntu 20.04 [\#114](https://github.com/theforeman/puppet-tftp/pull/114) ([ekohl](https://github.com/ekohl))
- Support Puppet 7 [\#111](https://github.com/theforeman/puppet-tftp/pull/111) ([ekohl](https://github.com/ekohl))

## [6.0.0](https://github.com/theforeman/puppet-tftp/tree/6.0.0) (2020-05-12)

[Full Changelog](https://github.com/theforeman/puppet-tftp/compare/5.0.2...6.0.0)

**Breaking changes:**

- Use modern facts [\#107](https://github.com/theforeman/puppet-tftp/issues/107)

**Implemented enhancements:**

- Add EL8 & Fedora 31, drop Fedora 26 [\#98](https://github.com/theforeman/puppet-tftp/pull/98) ([ekohl](https://github.com/ekohl))

## [5.0.2](https://github.com/theforeman/puppet-tftp/tree/5.0.2) (2020-02-11)

[Full Changelog](https://github.com/theforeman/puppet-tftp/compare/5.0.1...5.0.2)

**Implemented enhancements:**

- Add Debian 10 [\#100](https://github.com/theforeman/puppet-tftp/pull/100) ([mmoll](https://github.com/mmoll))

## [5.0.1](https://github.com/theforeman/puppet-tftp/tree/5.0.1) (2019-06-12)

[Full Changelog](https://github.com/theforeman/puppet-tftp/compare/5.0.0...5.0.1)

**Merged pull requests:**

- Allow `puppetlabs/stdlib` 6.x [\#95](https://github.com/theforeman/puppet-tftp/pull/95) ([alexjfisher](https://github.com/alexjfisher))

## [5.0.0](https://github.com/theforeman/puppet-tftp/tree/5.0.0) (2019-04-15)

[Full Changelog](https://github.com/theforeman/puppet-tftp/compare/4.4.0...5.0.0)

**Breaking changes:**

- drop Puppet 4 [\#93](https://github.com/theforeman/puppet-tftp/pull/93) ([mmoll](https://github.com/mmoll))
- drop EOL OSes [\#92](https://github.com/theforeman/puppet-tftp/pull/92) ([mmoll](https://github.com/mmoll))

## [4.4.0](https://github.com/theforeman/puppet-tftp/tree/4.4.0) (2019-01-10)

[Full Changelog](https://github.com/theforeman/puppet-tftp/compare/4.3.0...4.4.0)

**Implemented enhancements:**

- Support Puppet 6 [\#86](https://github.com/theforeman/puppet-tftp/pull/86) ([ekohl](https://github.com/ekohl))

**Merged pull requests:**

- Mark private classes for puppet-strings [\#88](https://github.com/theforeman/puppet-tftp/pull/88) ([ekohl](https://github.com/ekohl))

## [4.3.0](https://github.com/theforeman/puppet-tftp/tree/4.3.0) (2018-10-15)

[Full Changelog](https://github.com/theforeman/puppet-tftp/compare/4.2.1...4.3.0)

**Implemented enhancements:**

- Fixes [\#25190](https://projects.theforeman.org/issues/25190) - Allow overriding the tftp map source [\#82](https://github.com/theforeman/puppet-tftp/pull/82) ([ekohl](https://github.com/ekohl))
- Simplify service class & contain classes [\#80](https://github.com/theforeman/puppet-tftp/pull/80) ([ekohl](https://github.com/ekohl))

## [4.2.1](https://github.com/theforeman/puppet-tftp/tree/4.2.1) (2018-10-04)

[Full Changelog](https://github.com/theforeman/puppet-tftp/compare/4.2.0...4.2.1)

**Merged pull requests:**

- allow puppetlabs-stdlib 5.x [\#78](https://github.com/theforeman/puppet-tftp/pull/78) ([mmoll](https://github.com/mmoll))

## [4.2.0](https://github.com/theforeman/puppet-tftp/tree/4.2.0) (2018-07-16)

[Full Changelog](https://github.com/theforeman/puppet-tftp/compare/4.1.0...4.2.0)

**Implemented enhancements:**

- Support Ubuntu/bionic, drop Fedora 25 [\#72](https://github.com/theforeman/puppet-tftp/pull/72) ([mmoll](https://github.com/mmoll))

## [4.1.0](https://github.com/theforeman/puppet-tftp/tree/4.1.0) (2018-05-02)

[Full Changelog](https://github.com/theforeman/puppet-tftp/compare/4.0.0...4.1.0)

**Merged pull requests:**

- Clean up the configuration class [\#70](https://github.com/theforeman/puppet-tftp/pull/70) ([ekohl](https://github.com/ekohl))

## [4.0.0](https://github.com/theforeman/puppet-tftp/tree/4.0.0) (2018-01-25)

[Full Changelog](https://github.com/theforeman/puppet-tftp/compare/3.0.2...4.0.0)

**Breaking changes:**

- Update hiera yaml to version 5 [\#57](https://github.com/theforeman/puppet-tftp/pull/57) ([mmoll](https://github.com/mmoll))

**Implemented enhancements:**

- add option to manage root\_dir [\#67](https://github.com/theforeman/puppet-tftp/pull/67) ([bastelfreak](https://github.com/bastelfreak))
- remove EOL OSes, add new ones [\#63](https://github.com/theforeman/puppet-tftp/pull/63) ([mmoll](https://github.com/mmoll))
- Set the service for the Red Hat osfamily [\#59](https://github.com/theforeman/puppet-tftp/pull/59) ([ekohl](https://github.com/ekohl))

## 3.0.2
* Allow puppetlabs/xinetd 3.0.0
* Set the service for the Red Hat OS family

## 3.0.1
* Fix `invalid byte sequence in UTF-8` error

## 3.0.0
* Drop Puppet 3 support
* Add handling for some buggy PXE stacks

## 2.0.0
* Drop support for Ruby 1.8.7

## 1.8.2
* Fix strict variables compatibility on Arch Linux

## 1.8.1
* Mark compatibility with puppetlabs/xinetd 2.x

## 1.8.0
* Add support for Archlinux
* Add package, syslinux_package parameters to override package names
* Fix service resource provider under Ubuntu 16.04

## 1.7.0
* Add support for Ubuntu 16.04
* Support Puppet 3.0 minimum
* Support Fedora 21, remove Debian 6 (Squeeze)

## 1.6.0
* Add FreeBSD support
* Support Puppet 4 and future parser
* Remove trailing slashes of tftproot directories

## 1.5.1
* Improved linting, minor style fixes

## 1.5.0
* Support for Debian 8 (Jessie) syslinux package names
* Add root parameter to override root directory (#8942)

## 1.4.3
* Fix lint issues

## 1.4.2
* Fix Modulefile specification for Forge compatibility

## 1.4.1
* Specify xinetd version to workaround librarian-puppet bug

## 1.4.0
* Add Amazon Linux support
* Puppet 2.6 support deprecated
* Cleanup of manifest style
* Add tests


\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*

==> foreman-installer-3.17.0-rc1.tar.bz2: foreman-installer-3.17.0-rc1/modules/tftp/CHANGELOG.md <==
# Changelog

## [10.0.0](https://github.com/theforeman/puppet-tftp/tree/10.0.0) (2025-08-04)

[Full Changelog](https://github.com/theforeman/puppet-tftp/compare/9.1.0...10.0.0)

**Breaking changes:**

- Drop CentOS 8 & Debian 10 support [\#158](https://github.com/theforeman/puppet-tftp/pull/158) ([ekohl](https://github.com/ekohl))
- Drop EL7 support [\#157](https://github.com/theforeman/puppet-tftp/pull/157) ([ekohl](https://github.com/ekohl))
- Drop Amazon Linux specifics [\#156](https://github.com/theforeman/puppet-tftp/pull/156) ([ekohl](https://github.com/ekohl))

**Implemented enhancements:**

- Add AlmaLinux 8 & 9 support [\#151](https://github.com/theforeman/puppet-tftp/pull/151) ([archanaserver](https://github.com/archanaserver))

## [9.1.0](https://github.com/theforeman/puppet-tftp/tree/9.1.0) (2024-05-16)

[Full Changelog](https://github.com/theforeman/puppet-tftp/compare/9.0.0...9.1.0)

**Implemented enhancements:**

- Add support for Debian 12 [\#149](https://github.com/theforeman/puppet-tftp/pull/149) ([evgeni](https://github.com/evgeni))
- Add Ubuntu 22.04 support [\#148](https://github.com/theforeman/puppet-tftp/pull/148) ([evgeni](https://github.com/evgeni))

## [9.0.0](https://github.com/theforeman/puppet-tftp/tree/9.0.0) (2023-11-14)

[Full Changelog](https://github.com/theforeman/puppet-tftp/compare/8.0.0...9.0.0)

**Breaking changes:**

- Drop Fedora support [\#145](https://github.com/theforeman/puppet-tftp/pull/145) ([ekohl](https://github.com/ekohl))
- Drop Puppet 6 support [\#144](https://github.com/theforeman/puppet-tftp/pull/144) ([ekohl](https://github.com/ekohl))
- Drop Ubuntu 18.04 & Debian 9, add Red Hat 9 support [\#142](https://github.com/theforeman/puppet-tftp/pull/142) ([dvo-rak](https://github.com/dvo-rak))

**Implemented enhancements:**

- Add Puppet 8 support [\#140](https://github.com/theforeman/puppet-tftp/pull/140) ([bastelfreak](https://github.com/bastelfreak))
- puppetlabs/stdlib: Allow 9.x [\#139](https://github.com/theforeman/puppet-tftp/pull/139) ([bastelfreak](https://github.com/bastelfreak))
- make syslinux package management optional [\#138](https://github.com/theforeman/puppet-tftp/pull/138) ([UiP9AV6Y](https://github.com/UiP9AV6Y))

## [8.0.0](https://github.com/theforeman/puppet-tftp/tree/8.0.0) (2022-10-27)

[Full Changelog](https://github.com/theforeman/puppet-tftp/compare/7.2.0...8.0.0)

**Breaking changes:**

- Drop xinetd support [\#136](https://github.com/theforeman/puppet-tftp/pull/136) ([ekohl](https://github.com/ekohl))

**Implemented enhancements:**

- Update to voxpupuli-test 5 [\#135](https://github.com/theforeman/puppet-tftp/pull/135) ([ekohl](https://github.com/ekohl))

## [7.2.0](https://github.com/theforeman/puppet-tftp/tree/7.2.0) (2022-04-20)

[Full Changelog](https://github.com/theforeman/puppet-tftp/compare/7.1.0...7.2.0)

**Implemented enhancements:**

- CentOS Stream 9 support [\#126](https://github.com/theforeman/puppet-tftp/pull/126) ([ekohl](https://github.com/ekohl))

## [7.1.0](https://github.com/theforeman/puppet-tftp/tree/7.1.0) (2022-02-03)

[Full Changelog](https://github.com/theforeman/puppet-tftp/compare/7.0.0...7.1.0)

**Implemented enhancements:**

- puppetlabs/stdlib: Allow 8.x [\#129](https://github.com/theforeman/puppet-tftp/pull/129) ([bastelfreak](https://github.com/bastelfreak))
- Add Debian 11 support [\#125](https://github.com/theforeman/puppet-tftp/pull/125) ([ekohl](https://github.com/ekohl))

## [7.0.0](https://github.com/theforeman/puppet-tftp/tree/7.0.0) (2021-07-23)

[Full Changelog](https://github.com/theforeman/puppet-tftp/compare/6.0.0...7.0.0)

**Breaking changes:**

- Drop EL6, Debian 8, Ubuntu 16.04 [\#122](https://github.com/theforeman/puppet-tftp/pull/122) ([ehelms](https://github.com/ehelms))
- Drop Puppet 5 support [\#120](https://github.com/theforeman/puppet-tftp/pull/120) ([ehelms](https://github.com/ehelms))

**Implemented enhancements:**

- Allow Puppet 7 compatible versions of mods [\#116](https://github.com/theforeman/puppet-tftp/pull/116) ([ekohl](https://github.com/ekohl))
- Support Ubuntu 20.04 [\#114](https://github.com/theforeman/puppet-tftp/pull/114) ([ekohl](https://github.com/ekohl))
- Support Puppet 7 [\#111](https://github.com/theforeman/puppet-tftp/pull/111) ([ekohl](https://github.com/ekohl))

## [6.0.0](https://github.com/theforeman/puppet-tftp/tree/6.0.0) (2020-05-12)

[Full Changelog](https://github.com/theforeman/puppet-tftp/compare/5.0.2...6.0.0)

**Breaking changes:**

- Use modern facts [\#107](https://github.com/theforeman/puppet-tftp/issues/107)

**Implemented enhancements:**

- Add EL8 & Fedora 31, drop Fedora 26 [\#98](https://github.com/theforeman/puppet-tftp/pull/98) ([ekohl](https://github.com/ekohl))

## [5.0.2](https://github.com/theforeman/puppet-tftp/tree/5.0.2) (2020-02-11)

[Full Changelog](https://github.com/theforeman/puppet-tftp/compare/5.0.1...5.0.2)

**Implemented enhancements:**

- Add Debian 10 [\#100](https://github.com/theforeman/puppet-tftp/pull/100) ([mmoll](https://github.com/mmoll))

## [5.0.1](https://github.com/theforeman/puppet-tftp/tree/5.0.1) (2019-06-12)

[Full Changelog](https://github.com/theforeman/puppet-tftp/compare/5.0.0...5.0.1)

**Merged pull requests:**

- Allow `puppetlabs/stdlib` 6.x [\#95](https://github.com/theforeman/puppet-tftp/pull/95) ([alexjfisher](https://github.com/alexjfisher))

## [5.0.0](https://github.com/theforeman/puppet-tftp/tree/5.0.0) (2019-04-15)

[Full Changelog](https://github.com/theforeman/puppet-tftp/compare/4.4.0...5.0.0)

**Breaking changes:**

- drop Puppet 4 [\#93](https://github.com/theforeman/puppet-tftp/pull/93) ([mmoll](https://github.com/mmoll))
- drop EOL OSes [\#92](https://github.com/theforeman/puppet-tftp/pull/92) ([mmoll](https://github.com/mmoll))

## [4.4.0](https://github.com/theforeman/puppet-tftp/tree/4.4.0) (2019-01-10)

[Full Changelog](https://github.com/theforeman/puppet-tftp/compare/4.3.0...4.4.0)

**Implemented enhancements:**

- Support Puppet 6 [\#86](https://github.com/theforeman/puppet-tftp/pull/86) ([ekohl](https://github.com/ekohl))

**Merged pull requests:**

- Mark private classes for puppet-strings [\#88](https://github.com/theforeman/puppet-tftp/pull/88) ([ekohl](https://github.com/ekohl))

## [4.3.0](https://github.com/theforeman/puppet-tftp/tree/4.3.0) (2018-10-15)

[Full Changelog](https://github.com/theforeman/puppet-tftp/compare/4.2.1...4.3.0)

**Implemented enhancements:**

- Fixes [\#25190](https://projects.theforeman.org/issues/25190) - Allow overriding the tftp map source [\#82](https://github.com/theforeman/puppet-tftp/pull/82) ([ekohl](https://github.com/ekohl))
- Simplify service class & contain classes [\#80](https://github.com/theforeman/puppet-tftp/pull/80) ([ekohl](https://github.com/ekohl))

## [4.2.1](https://github.com/theforeman/puppet-tftp/tree/4.2.1) (2018-10-04)

[Full Changelog](https://github.com/theforeman/puppet-tftp/compare/4.2.0...4.2.1)

**Merged pull requests:**

- allow puppetlabs-stdlib 5.x [\#78](https://github.com/theforeman/puppet-tftp/pull/78) ([mmoll](https://github.com/mmoll))

## [4.2.0](https://github.com/theforeman/puppet-tftp/tree/4.2.0) (2018-07-16)

[Full Changelog](https://github.com/theforeman/puppet-tftp/compare/4.1.0...4.2.0)

**Implemented enhancements:**

- Support Ubuntu/bionic, drop Fedora 25 [\#72](https://github.com/theforeman/puppet-tftp/pull/72) ([mmoll](https://github.com/mmoll))

## [4.1.0](https://github.com/theforeman/puppet-tftp/tree/4.1.0) (2018-05-02)

[Full Changelog](https://github.com/theforeman/puppet-tftp/compare/4.0.0...4.1.0)

**Merged pull requests:**

- Clean up the configuration class [\#70](https://github.com/theforeman/puppet-tftp/pull/70) ([ekohl](https://github.com/ekohl))

## [4.0.0](https://github.com/theforeman/puppet-tftp/tree/4.0.0) (2018-01-25)

[Full Changelog](https://github.com/theforeman/puppet-tftp/compare/3.0.2...4.0.0)

**Breaking changes:**

- Update hiera yaml to version 5 [\#57](https://github.com/theforeman/puppet-tftp/pull/57) ([mmoll](https://github.com/mmoll))

**Implemented enhancements:**

- add option to manage root\_dir [\#67](https://github.com/theforeman/puppet-tftp/pull/67) ([bastelfreak](https://github.com/bastelfreak))
- remove EOL OSes, add new ones [\#63](https://github.com/theforeman/puppet-tftp/pull/63) ([mmoll](https://github.com/mmoll))
- Set the service for the Red Hat osfamily [\#59](https://github.com/theforeman/puppet-tftp/pull/59) ([ekohl](https://github.com/ekohl))

## 3.0.2
* Allow puppetlabs/xinetd 3.0.0
* Set the service for the Red Hat OS family

## 3.0.1
* Fix `invalid byte sequence in UTF-8` error

## 3.0.0
* Drop Puppet 3 support
* Add handling for some buggy PXE stacks

## 2.0.0
* Drop support for Ruby 1.8.7

## 1.8.2
* Fix strict variables compatibility on Arch Linux

## 1.8.1
* Mark compatibility with puppetlabs/xinetd 2.x

## 1.8.0
* Add support for Archlinux
* Add package, syslinux_package parameters to override package names
* Fix service resource provider under Ubuntu 16.04

## 1.7.0
* Add support for Ubuntu 16.04
* Support Puppet 3.0 minimum
* Support Fedora 21, remove Debian 6 (Squeeze)

## 1.6.0
* Add FreeBSD support
* Support Puppet 4 and future parser
* Remove trailing slashes of tftproot directories

## 1.5.1
* Improved linting, minor style fixes

## 1.5.0
* Support for Debian 8 (Jessie) syslinux package names
* Add root parameter to override root directory (#8942)

## 1.4.3
* Fix lint issues

## 1.4.2
* Fix Modulefile specification for Forge compatibility

## 1.4.1
* Specify xinetd version to workaround librarian-puppet bug

## 1.4.0
* Add Amazon Linux support
* Puppet 2.6 support deprecated
* Cleanup of manifest style
* Add tests


\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
